@@ -12,8 +12,8 @@ logger = logging.getLogger(__name__)
 
 NLG_QUERY = """
 query(
-    $template: String!
-    $arguments: NlgRequestArguments!
+    $template: StringOrListOfStrings!
+    $arguments: Any
     $tracker: ConversationInput
     $channel: NlgRequestChannel
 ) {
@@ -40,7 +40,7 @@ def nlg_response_format_spec():
     return {
         "type": "object",
         "properties": {
-            "text": {"type": "string"},
+            "text": {"type": ["string", "null"]},
             "buttons": {"type": ["array", "null"], "items": {"type": "object"}},
             "elements": {"type": ["array", "null"], "items": {"type": "object"}},
             "attachment": {"type": ["object", "null"]},
@@ -106,12 +106,18 @@ class GraphQLNaturalLanguageGenerator(NaturalLanguageGenerator):
         **kwargs: Any,
     ) -> List[Dict[Text, Any]]:
 
+        fallback_language_slot = tracker.slots.get("fallback_language")
+        fallback_language = (
+            fallback_language_slot.initial_value if fallback_language_slot else None
+        )
+        language = tracker.latest_message.metadata.get("language") or fallback_language
+
         body = nlg_request_format(
             template_name,
             tracker,
             output_channel,
             **kwargs,
-            language=tracker.latest_message.metadata.get("language"),
+            language=language,
             projectId=os.environ.get("BF_PROJECT_ID"),
         )
 
@@ -124,7 +130,9 @@ class GraphQLNaturalLanguageGenerator(NaturalLanguageGenerator):
             if "graphql" in self.nlg_endpoint.url:
                 from sgqlc.endpoint.http import HTTPEndpoint
 
-                response = HTTPEndpoint(self.nlg_endpoint.url)(NLG_QUERY, body)
+                api_key = os.environ.get("API_KEY")
+                headers = [{"Authorization": api_key}] if api_key else []
+                response = HTTPEndpoint(self.nlg_endpoint.url, *headers)(NLG_QUERY, body)
                 response = response["data"]["getResponse"]
             else:
                 response = await self.nlg_endpoint.request(
@@ -133,13 +141,13 @@ class GraphQLNaturalLanguageGenerator(NaturalLanguageGenerator):
                 response = response[0]  # legacy route, use first message in seq
         except Exception as e:
             logger.error("NLG web endpoint returned an invalid response: {}".format(e))
-            return [{"text": template_name}]
+            return {"text": template_name}
 
         if self.validate_response(response):
             return response
         else:
             logger.error("NLG web endpoint returned an invalid response.")
-            return [{"text": template_name}]
+            return {"text": template_name}
 
     @staticmethod
     def validate_response(content: Optional[Dict[Text, Any]]) -> bool:
